# omniidl backend code

This does not include all the code to run omniidl, only the 
enough to write custom backends for omniidl. You can download
all the omniidl code at the following link:

http://omniorb.sourceforge.net/

For testing I recommend setting up a python virtual environment
and running `pip install .` in the root of the directory. Once
you activate the virtual environment, `import omniidl` should work
with no errors.
